@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -94,7 +94,7 @@ sub LoadDefaults {
     # ScriptAlias
     # Prefix to index.pl used as ScriptAlias in web config
     # (Used when emailing links to agents).
-    $Self->{ScriptAlias} = 'otrs/';
+    $Self->{ScriptAlias} = 'znuny/';
 
     # AdminEmail
     # (Email of the system admin.)
@@ -118,11 +118,11 @@ sub LoadDefaults {
 
     # Database
     # (The database name.)
-    $Self->{Database} = 'otrs';
+    $Self->{Database} = 'znuny';
 
     # DatabaseUser
     # (The database user.)
-    $Self->{DatabaseUser} = 'otrs';
+    $Self->{DatabaseUser} = 'znuny';
 
     # DatabasePw
     # (The password of database user.)
@@ -287,7 +287,7 @@ sub LoadDefaults {
 
     # Frontend::WebPath
     # (URL base path of icons, CSS and Java Script.)
-    $Self->{'Frontend::WebPath'} = '/otrs-web/';
+    $Self->{'Frontend::WebPath'} = '/znuny-web/';
 
     # Frontend::JavaScriptPath
     # (URL JavaScript path.)
@@ -370,7 +370,7 @@ sub LoadDefaults {
 #    $Self->{'LogModule::SysLog::Charset'} = 'utf-8';
 
     # param for LogModule Kernel::System::Log::File (required!)
-    $Self->{'LogModule::LogFile'} = '/tmp/otrs.log';
+    $Self->{'LogModule::LogFile'} = '/tmp/znuny.log';
 
     # param if the date (yyyy-mm) should be added as suffix to
     # logfile [0|1]
@@ -531,6 +531,7 @@ sub LoadDefaults {
 #    $Self->{'AuthSyncModule::LDAP::Host'} = 'ldap.example.com';
 #    $Self->{'AuthSyncModule::LDAP::BaseDN'} = 'dc=example,dc=com';
 #    $Self->{'AuthSyncModule::LDAP::UID'} = 'uid';
+#    $Self->{'AuthSyncModule::LDAP::GroupDN'} = 'cn=otrsallow,ou=posixGroups,dc=example,dc=com';
 
     # The following is valid but would only be necessary if the
     # anonymous user do NOT have permission to read from the LDAP tree
@@ -720,16 +721,9 @@ sub LoadDefaults {
     # agent interface notification module to check the admin user id
     # (don't work with user id 1 notification)
     $Self->{'Frontend::NotifyModule'} = {
-        '1100-OTRSBusiness' => {
-            Group  => 'admin',
-            Module => 'Kernel::Output::HTML::Notification::AgentOTRSBusiness',
-        },
         '2000-UID-Check' => {
             Module => 'Kernel::Output::HTML::Notification::UIDCheck',
         },
-        '2500-AgentSessionLimit' => {
-          'Module' => 'Kernel::Output::HTML::Notification::AgentSessionLimit',
-        },
         '5000-SystemConfigurationIsDirty-Check' => {
             Group  => 'admin',
             Module => 'Kernel::Output::HTML::Notification::SystemConfigurationIsDirtyCheck',
@@ -887,7 +881,7 @@ sub LoadDefaults {
 #    $Self->{WebUploadCacheModule} = 'Kernel::System::Web::UploadCache::FS';
 
     # CGILogPrefix
-    $Self->{CGILogPrefix} = 'OTRS-CGI';
+    $Self->{CGILogPrefix} = 'Znuny-CGI';
 
     # --------------------------------------------------- #
     # Agent Web Interface
@@ -927,7 +921,7 @@ sub LoadDefaults {
     # directories                                         #
     # --------------------------------------------------- #
     # root directory
-    $Self->{Home} = '/opt/otrs';
+    $Self->{Home} = '/opt/znuny';
 
     # tmp dir
     $Self->{TempDir} = '<OTRS_CONFIG_Home>/var/tmp';
@@ -943,29 +937,15 @@ sub LoadDefaults {
     # CommonCSS                                           #
     # --------------------------------------------------- #
 
-    # Customer Common CSS
-    $Self->{'Loader::Customer::CommonCSS'}->{'000-Framework'} = [
-        'Core.Color.css',
-        'Core.Reset.css',
-        'Core.Default.css',
-        'Core.Form.css',
-        'Core.Dialog.css',
-        'Core.Tooltip.css',
-        'Core.Login.css',
-        'Core.Control.css',
-        'Core.Table.css',
-        'Core.TicketZoom.css',
-        'Core.InputFields.css',
-        'Core.Print.css',
-        'Core.Animations.css',
-    ];
-
     # Agent Common CSS
     $Self->{'Loader::Agent::CommonCSS'}->{'000-Framework'} = [
         'Core.Color.css',
+        'Core.Vars.css',
         'Core.Reset.css',
+        'Core.Reset.Forwwward.css',
         'Core.Default.css',
         'Core.Header.css',
+        'Core.Overview.css',
         'Core.OverviewControl.css',
         'Core.OverviewSmall.css',
         'Core.OverviewMedium.css',
@@ -983,6 +963,32 @@ sub LoadDefaults {
         'Core.InputFields.css',
         'Core.Print.css',
         'Core.Animations.css',
+        'Core.Components.css',
+        'Core.FlexboxModel.css',
+        'Core.Typography.css',
+    ];
+
+    # Customer Common CSS
+    $Self->{'Loader::Customer::CommonCSS'}->{'000-Framework'} = [
+        'Core.Color.css',
+        'Core.Vars.css',
+        'Core.Reset.css',
+        'Core.Reset.Forwwward.css',
+        'Core.Default.css',
+        'Core.Form.css',
+        'Core.Dialog.css',
+        'Core.Tooltip.css',
+        'Core.Login.css',
+        'Core.Control.css',
+        'Core.Table.css',
+        'Core.TicketZoom.css',
+        'Core.InputFields.css',
+        'Core.Print.css',
+        'Core.Animations.css',
+        'Core.FlexboxModel.css',
+        'Core.Footer.css',,
+        'Core.PageLayout.css',
+        'Core.Components.css'
     ];
 
     # --------------------------------------------------- #
@@ -991,10 +997,10 @@ sub LoadDefaults {
 
     # Customer Common JS
     $Self->{'Loader::Customer::CommonJS'}->{'000-Framework'} = [
-        'thirdparty/jquery-3.6.0/jquery.js',
+        'thirdparty/jquery-3.7.0/jquery.js',
         'thirdparty/jquery-browser-detection/jquery-browser-detection.js',
         'thirdparty/jquery-validate-1.16.0/jquery.validate.js',
-        'thirdparty/jquery-ui-1.13.1/jquery-ui.js',
+        'thirdparty/jquery-ui-1.13.3/jquery-ui.js',
         'thirdparty/jquery-pubsub/pubsub.js',
         'thirdparty/jquery-jstree-3.3.7/jquery.jstree.js',
         'thirdparty/nunjucks-3.2.2/nunjucks.min.js',
@@ -1029,9 +1035,9 @@ sub LoadDefaults {
 
     # Agent Common JS
     $Self->{'Loader::Agent::CommonJS'}->{'000-Framework'} = [
-        'thirdparty/jquery-3.6.0/jquery.js',
+        'thirdparty/jquery-3.7.0/jquery.js',
         'thirdparty/jquery-browser-detection/jquery-browser-detection.js',
-        'thirdparty/jquery-ui-1.13.1/jquery-ui.js',
+        'thirdparty/jquery-ui-1.13.3/jquery-ui.js',
         'thirdparty/jquery-ui-touch-punch-0.2.3/jquery.ui.touch-punch.js',
         'thirdparty/jquery-validate-1.16.0/jquery.validate.js',
         'thirdparty/jquery-pubsub/pubsub.js',
@@ -1045,6 +1051,7 @@ sub LoadDefaults {
         'Core.Data.js',
         'Core.Config.js',
         'Core.Language.js',
+        'Core.Activity.js',
         'Core.Template.js',
         'Core.JSON.js',
         'Core.App.js',
@@ -1093,7 +1100,7 @@ sub LoadDefaults {
     # Package::RepositoryList
     # (repository list)
 #    $Self->{'Package::RepositoryList'} = {
-#        'ftp://ftp.example.com/pub/otrs/misc/packages/' => '[Example] ftp://ftp.example.com/',
+#        'ftp://ftp.example.com/pub/znuny/misc/packages/' => '[Example] ftp://ftp.example.com/',
 #    };
 
     # Package::Timeout
@@ -1109,7 +1116,7 @@ sub LoadDefaults {
     # --------------------------------------------------- #
     $Self->{PGP}            = 0;
     $Self->{'PGP::Bin'}     = '/usr/bin/gpg';
-    $Self->{'PGP::Options'} = '--homedir /opt/otrs/.gnupg/ --batch --no-tty --yes';
+    $Self->{'PGP::Options'} = '--homedir /opt/znuny/.gnupg/ --batch --no-tty --yes';
 
 #    $Self->{'PGP::Options'} = '--batch --no-tty --yes';
 #    $Self->{'PGP::Key::Password'}->{'D2DF79FA'} = 1234;
@@ -1252,7 +1259,7 @@ You can log in via the following URL:
 
     # CustomerGroupSupport (0 = compat. to OTRS 1.1 or lower)
     # (if this is 1, the you need to set the group <-> customer user
-    # relations! http://host/otrs/index.pl?Action=AdminCustomerUserGroup
+    # relations! http://host/znuny/index.pl?Action=AdminCustomerUserGroup
     # otherway, each user is ro/rw in each group!)
     $Self->{CustomerGroupSupport} = 0;
 
@@ -1750,12 +1757,11 @@ via the Preferences button after logging in.
         NavBarName => 'Admin',
         Title      => '',
     };
-    $Self->{'Loader::Module::Admin'}->{'000-Defaults'} = {
+    $Self->{'Loader::Module::Admin'}->{'001-Framework'} = {
         CSS => [
             'Core.Agent.Admin.css',
         ],
         JavaScript => [
-            'Core.Agent.Admin.js',
             'Core.UI.AllocationList.js',
             'Core.Agent.TableFilters.js',
         ],
@@ -1808,7 +1814,7 @@ via the Preferences button after logging in.
         NavBarName => 'Admin',
         Title      => 'System Log',
     };
-    $Self->{'Loader::Module::AdminLog'}->{'000-Defaults'} = {
+    $Self->{'Loader::Module::AdminLog'}->{'001-Framework'} = {
         JavaScript => [
           'Core.Agent.Admin.Log.js'
         ],
@@ -1833,7 +1839,7 @@ via the Preferences button after logging in.
         Title        => 'System Configuration',
         NavBarName   => 'Admin',
     };
-    $Self->{'Loader::Module::AdminSystemConfiguration'}->{'000-Defaults'} = {
+    $Self->{'Loader::Module::AdminSystemConfiguration'}->{'001-Framework'} = {
         CSS => [
             'Core.Agent.Admin.SystemConfiguration.css',
         ],
