@@ -307,20 +307,20 @@ Core.UI.RichTextEditor = (function (TargetNS) {
 
         // set default editor config, but allow custom config for other types for editors
         /*eslint-disable camelcase */
-        RemovedCKEditorPlugins = 'devtools,image,flash,mathjax,embed,exportpdf,sourcedialog,bbcode,divarea,elementspath,stylesheetparser';
+        RemovedCKEditorPlugins = 'devtools,image,flash,mathjax,embed,embedsemantic,exportpdf,sourcedialog,bbcode,divarea,elementspath,stylesheetparser,autogrow';
         if (!CheckFormID($EditorArea).length) {
             RemovedCKEditorPlugins += ',uploadimage';
         }
 
         EditorConfig = {
-            // customConfig:              '', // avoid loading external config files
+            // customConfig:           '', // avoid loading external config files
+            versionCheck:              false,
             disableNativeSpellChecker: false,
             defaultLanguage:           UserLanguage,
             language:                  UserLanguage,
             width:                     Core.Config.Get('RichText.Width', 620),
             resize_minWidth:           Core.Config.Get('RichText.Width', 620),
             height:                    Core.Config.Get('RichText.Height', 320),
-            autoGrow_minHeight:        Core.Config.Get('RichText.Height', 320),
             removePlugins:             RemovedCKEditorPlugins,
             forcePasteAsPlainText:     false,
             format_tags:               Core.Config.Get('RichText.FormatTags', 'p;h1;h2;h3;h4;h5;h6;pre'),
@@ -335,7 +335,8 @@ Core.UI.RichTextEditor = (function (TargetNS) {
             filebrowserUploadUrl:      UploadURL,
             extraPlugins:              Core.Config.Get('RichText.ExtraPlugins', 'splitquote,contextmenu_linkopen'),
             entities:                  false,
-            skin:                      'moono-lisa'
+            skin:                      'moono-lisa',
+            contentsCss:               [ Core.Config.Get('RichText.ContentsCss', '') ]
         };
         /*eslint-enable camelcase */
 
@@ -422,6 +423,14 @@ Core.UI.RichTextEditor = (function (TargetNS) {
             };
             /* eslint-enable no-unused-vars */
 
+            // Needed for clientside validation of RTE
+            CKEDITOR.instances[EditorID].on('blur', function () {
+                CKEDITOR.instances[EditorID].updateElement();
+                if (!$EditorArea.hasClass('Error')) {
+                    Core.Form.Validate.ValidateElement($EditorArea);
+                }
+            });
+
             // needed for client-side validation
             CKEDITOR.instances[EditorID].on('focus', function () {
 
